<?php

namespace App\Form;

use App\Entity\Etablissement;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use App\Enum\SecteurEnum;
use App\Enum\EtatEtabEnum;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;

class EtablissementType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options): void
    {
        $builder
            ->add('numero_uai')
            ->add('secteur', ChoiceType::class, [
                'choices' => SecteurEnum::getChoices(),
                'label' => 'Secteur',
                'choice_value' => function ($secteur) {
                    if ($secteur instanceof SecteurEnum) {
                        return $secteur->value;
                    }
                    return $secteur; // Accepte les chaînes de caractères directement
                },
            ])
            ->add('appellation_officielle')
            ->add('adresse')
            ->add('code_postal')
            ->add('commune')
            ->add('latitude')
            ->add('longitude')
            ->add('nature_uai')
            ->add('nature_libe')
            ->add('etat_etablissement_libe', ChoiceType::class, [
                'choices' => EtatEtabEnum::getChoices(),
                'label' => 'État de l\'établissement',
                'choice_value' => function ($etat) {
                    if ($etat instanceof EtatEtabEnum) {
                        return $etat->value;
                    }
                    return $etat; // Accepte les chaînes de caractères directement
                },
            ])
            ->add('code_departement')
            ->add('code_region')
            ->add('code_academie')
            ->add('code_commune')
            ->add('departement')
            ->add('region')
            ->add('academie')
            ->add('type_contrat')
            ->add('libelle_type_contrat')
            ->add('code_ministere')
            ->add('libelle_ministere')
            ->add('date_ouverture', null, [
                'widget' => 'single_text',
            ])
            ->add('submit', SubmitType::class, [
                'label' => 'Enregistrer',
            ])
        ;
    }

    public function configureOptions(OptionsResolver $resolver): void
    {
        $resolver->setDefaults([
            'data_class' => Etablissement::class,
        ]);
    }
}
